@@ -64,6 +64,21 @@ class BaseEnvEnum(str, enum.Enum):
             return value
 
 
+def normalize_parameter_name(param_name: str) -> str:
+    """
+    AWS has limitation that the name cannot be prefixed with "aws" or "ssm",
+    so this method will automatically add prepend character to the name.
+
+    Ref:
+
+    - AWS Parameter Name Limitation: https://docs.aws.amazon.com/cli/latest/reference/ssm/put-parameter.html#options
+    """
+    if param_name.startswith("aws") or param_name.startswith("ssm"):
+        return f"p-{param_name}"
+    else:
+        return param_name
+
+
 @dataclasses.dataclass
 class BaseEnv:
     """
@@ -137,24 +152,12 @@ class BaseEnv:
     @cached_property
     def parameter_name(self) -> str:
         """
-        Return the aws SSM parameter name for this project. Usually, it is
-        the name as the "${project_name}-${env_name}"". AWS has limitation that
-        the name cannot be prefixed with "aws" or "ssm", so this method will
-        automatically add prepend character to the name
+        Return the per-environment AWS SSM Parameter name.
+        Usually, the naming convention is "${project_name}-${env_name}"".
 
         Example: "my_project-dev"
-
-        Ref:
-
-        - AWS Parameter Name Limitation: https://docs.aws.amazon.com/cli/latest/reference/ssm/put-parameter.html#options
         """
-        if (
-            self.prefix_name_snake.startswith("aws")
-            or self.prefix_name_snake.startswith("ssm")
-        ):
-            return f"p-{self.prefix_name_snake}"
-        else:
-            return self.prefix_name_snake
+        return normalize_parameter_name(self.prefix_name_snake)
 
 
 @dataclasses.dataclass
@@ -231,6 +234,16 @@ class BaseConfig:
     def project_name_snake(self) -> str:
         return slugify(self.project_name, delim="_")
 
+    @cached_property
+    def parameter_name(self) -> str:
+        """
+        Return the all-environment AWS SSM Parameter name.
+        Usually, the naming convention is "${project_name}".
+
+        Example: "my_project-dev"
+        """
+        return normalize_parameter_name(self.project_name_snake)
+
     # don't put type hint for return value, it should return a
     # user defined subclass, which is impossible to predict.
     def get_env(self, env_name: T.Union[str, BaseEnvEnum]):
@@ -244,7 +257,7 @@ class BaseConfig:
         return self.Env(**data)
 
     @classmethod
-    def get_current_env(cls) -> str:
+    def get_current_env(cls) -> str:  # pragma: no cover
         """
         An abstract method that can figure out what is the environment this config
         should deal with. For example, you can define the git feature branch
@@ -275,6 +288,7 @@ class BaseConfig:
         env_enum_class: T.Type[BaseEnvEnum],
         path_config: T.Optional[str] = None,
         path_secret_config: T.Optional[str] = None,
+        bsm: T.Optional["boto_session_manager.BotoSesManager"] = None,
         parameter_name: T.Optional[str] = None,
         parameter_with_encryption: T.Optional[bool] = None,
         s3path_config: T.Optional[str] = None,
@@ -308,11 +322,12 @@ class BaseConfig:
         elif (parameter_name is not None) and (
             parameter_with_encryption is not None
         ):  # pragma: no cover
-            aws_secret = pysecret.AWSSecret(boto_session=boto3.session.Session())
-            parameter_data = aws_secret.get_parameter_data(
+            parameter = pysecret.Parameter.load(
+                ssm_client=bsm.ssm_client,
                 name=parameter_name,
-                with_encryption=parameter_with_encryption,
+                with_decryption=parameter_with_encryption,
             )
+            parameter_data = parameter.json_dict
             return cls(
                 data=parameter_data["data"],
                 secret_data=parameter_data["secret_data"],
@@ -320,12 +335,11 @@ class BaseConfig:
                 EnvEnum=env_enum_class,
             )
         elif s3path_config is not None:  # pragma: no cover
-            s3_client = boto3.client("s3")
             parts = s3path_config.split("/", 3)
             bucket = parts[2]
             key = parts[3]
             config_data = json_loads(
-                s3_client.get_object(Bucket=bucket, Key=key)["Body"]
+                bsm.s3_client.get_object(Bucket=bucket, Key=key)["Body"]
                 .read()
                 .decode("utf-8")
             )
@@ -359,7 +373,7 @@ class BaseConfig:
 
         # manually add all env parameter, the name is project_name only
         # without env_name
-        parameter_name = self.project_name_snake
+        parameter_name = self.parameter_name
         parameter_data = {"data": self.data, "secret_data": self.secret_data}
         parameter_list.append(
             (parameter_name, parameter_data, self.project_name, "all")
@@ -388,7 +402,7 @@ class BaseConfig:
 
     def deploy(
         self,
-        bsm: T.Optional["boto_session_manager.BotoSesManager"] = None,
+        bsm: "boto_session_manager.BotoSesManager",
         parameter_with_encryption: T.Optional[bool] = None,
         s3dir_config: T.Optional[str] = None,
     ):  # pragma: no cover
@@ -407,7 +421,7 @@ class BaseConfig:
 
             this function should ONLY run from the project admin's trusted laptop.
         """
-        if (bsm is not None) and (parameter_with_encryption is not None):
+        if parameter_with_encryption is not None:
             # validate arguments
             if not (
                 (parameter_with_encryption is True)
@@ -432,7 +446,7 @@ class BaseConfig:
                         EnvName=env_name,
                     ),
                 )
-        elif (bsm is not None) and (s3dir_config is not None):
+        elif s3dir_config is not None:
             if not s3dir_config.endswith("/"):
                 raise ValueError(
                     "s3dir_config has to be a folder and end with /, "
@@ -470,10 +484,10 @@ class BaseConfig:
 
     def delete(
         self,
-        bsm: T.Optional["boto_session_manager.BotoSesManager"] = None,
+        bsm: "boto_session_manager.BotoSesManager",
         use_parameter_store: T.Optional[bool] = None,
         s3dir_config: T.Optional[str] = None,
-    ):
+    ):  # pragma: no cover
         """
         Delete the all project config of all environments from configuration store.
 
@@ -522,4 +536,4 @@ class BaseConfig:
                 "you want to delete config from AWS Parameter Store.\n"
                 "2. set ``s3dir_config`` similar to s3://my-bucket/my-project/ "
                 "to indicate that you want to delete config file from S3."
-            )
\ No newline at end of file
+            )
